Acknowledgement
===============

.. only:: html or text

   We would like to express our gratitude
   to Dr. |~| Đoàn Nhật Quang for providing us
   instruction and feedback during his supervision.  We would also like to
   extend our sincere thanks to Dr. |~| Trần Giang Sơn
   for his support with USTH ICTLab's server that we used
   for testing our deployment.

.. raw:: latex

   We would like to express our gratitude
   to {\selectlanguage{vietnamese}Dr.~Đoàn Nhật Quang} for providing us
   instruction and feedback during his supervision.  We would also like to
   extend our sincere thanks to {\selectlanguage{vietnamese}Dr.~Trần Giang Sơn}
   for his support with USTH ICTLab's server that we used
   for testing our deployment.

We would also like to thank Philip Jones, the author and maintainer of
the framework Quart, as well as the maintainers of RethinkDB for their timely
technical support and bug fixes.  The following organizations are also
appreciated for providing their services free of charge:

- Matrix.org (instant messaging server)
- GitHub (code hosting and collaboration)
- SourceHut (automated CI/CD)
- PlantUML web server (diagrams generation)
